@@ -1,4 +1,4 @@
-// SPDX-License-Identifier: GPL-2.0
+/* SPDX-License-Identifier: GPL-2.0 */
 /* Copyright(c) 1999 - 2023 Intel Corporation. */
 
 #include "ixgbevf.h"
@@ -2458,38 +2458,6 @@ void _kc_ethtool_intersect_link_masks(struct ethtool_link_ksettings *dst,
 }
 #endif /* 4.15.0 */
 
-/*****************************************************************************/
-#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,16,0))
-#if !(RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(8,0)) && \
-     !(SLE_VERSION_CODE >= SLE_VERSION(12,5,0) && \
-       SLE_VERSION_CODE < SLE_VERSION(15,0,0) || \
-       SLE_VERSION_CODE >= SLE_VERSION(15,1,0))
-#if BITS_PER_LONG == 64
-/**
- * bitmap_from_arr32 - copy the contents of u32 array of bits to bitmap
- * @bitmap: array of unsigned longs, the destination bitmap
- * @buf: array of u32 (in host byte order), the source bitmap
- * @nbits: number of bits in @bitmap
- */
-void bitmap_from_arr32(unsigned long *bitmap, const u32 *buf, unsigned int nbits)
-{
-	unsigned int i, halfwords;
-
-	halfwords = DIV_ROUND_UP(nbits, 32);
-	for (i = 0; i < halfwords; i++) {
-		bitmap[i/2] = (unsigned long) buf[i];
-		if (++i < halfwords)
-			bitmap[i/2] |= ((unsigned long) buf[i]) << 32;
-	}
-
-	/* Clear tail bits in last word beyond nbits. */
-	if (nbits % BITS_PER_LONG)
-		bitmap[(halfwords - 1) / 2] &= BITMAP_LAST_WORD_MASK(nbits);
-}
-#endif /* BITS_PER_LONG == 64 */
-#endif /* !(RHEL >= 8.0) && !(SLES >= 12.5 && SLES < 15.0 || SLES >= 15.1) */
-#endif /* 4.16.0 */
-
 /*****************************************************************************/
 #if (LINUX_VERSION_CODE < KERNEL_VERSION(4,17,0))
 /* PCIe link information */
@@ -2699,7 +2667,7 @@ u64 _kc_pci_get_dsn(struct pci_dev *dev)
 }
 #endif /* 5.7.0 */
 
-#ifdef NEED_DEVM_KASPRINTF
+#ifdef NEED_DEVM_KVASPRINTF
 char *devm_kvasprintf(struct device *dev, gfp_t gfp, const char *fmt,
 		      va_list ap)
 {
@@ -2719,7 +2687,9 @@ char *devm_kvasprintf(struct device *dev, gfp_t gfp, const char *fmt,
 
 	return p;
 }
+#endif /* NEED_DEVM_KVASPRINTF */
 
+#ifdef NEED_DEVM_KASPRINTF
 char *devm_kasprintf(struct device *dev, gfp_t gfp, const char *fmt, ...)
 {
 	va_list ap;
